@@ -1,10 +1,12 @@
 from pydocstringformatter.utils.argument_parsing import (
-    _parse_arguments,
+    _parse_command_line_arguments,
+    _parse_toml_file,
     _register_arguments,
 )
 from pydocstringformatter.utils.exceptions import (
     ParsingError,
     PydocstringFormatterError,
+    TomlParsingError,
 )
 from pydocstringformatter.utils.find_docstrings import _is_docstring
 from pydocstringformatter.utils.find_python_file import _find_python_files
@@ -12,8 +14,10 @@ from pydocstringformatter.utils.find_python_file import _find_python_files
 __all__ = [
     "_find_python_files",
     "_is_docstring",
-    "_parse_arguments",
+    "_parse_command_line_arguments",
     "_register_arguments",
     "PydocstringFormatterError",
     "ParsingError",
+    "_parse_toml_file",
+    "TomlParsingError",
 ]
